package com.afp.ordermanagement.service;


import org.apache.velocity.exception.ResourceNotFoundException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.config.ConfigDataResourceNotFoundException;
import org.springframework.stereotype.Service;
import org.springframework.kafka.core.KafkaTemplate;

import java.sql.SQLOutput;

@Service
public class Producer {

    private static final Logger logger = LoggerFactory.getLogger(Producer.class);
    private static final String MANAGER_TOPIC = "managers";
    private static final String ORDER_TOPIC = "orders";

    private KafkaTemplate<String, String> kafkaTemplate;

    public Producer(KafkaTemplate<String, String> kafkaTemplate) {
        this.kafkaTemplate = kafkaTemplate;
    }

    /**
     * DESC -   Sending orderId as a message to ORDER_TOPIC for warehouse to consume
     * @param id
     * @throws ResourceNotFoundException
     * @throws IllegalArgumentException
     */
    public void sendOrderId(String id) {
        try {
            logger.info(String.format("#### -> Order id sent to warehouse: %s", id));
            kafkaTemplate.send(ORDER_TOPIC, id);
        } catch (ResourceNotFoundException e) {
            logger.error("Order with that Id does not exist, exception caught: " + e);
        } catch (IllegalArgumentException e) {
            logger.error("Not a valid input, exception caught: " + e);
        }



    }

}
